@@ -79,25 +79,25 @@ int KonversationApplication::newInstance()
 
     if (!mainWindow)
     {
-        connect(this, TQT_SIGNAL(shutDown()), this, TQT_SLOT(prepareShutdown()));
+        connect(this, TQ_SIGNAL(shutDown()), this, TQ_SLOT(prepareShutdown()));
 
-        m_connectionManager = new ConnectionManager(TQT_TQOBJECT(this));
+        m_connectionManager = new ConnectionManager(this);
 
-        m_awayManager = new AwayManager(TQT_TQOBJECT(this));
+        m_awayManager = new AwayManager(this);
 
-        connect(m_connectionManager, TQT_SIGNAL(identityOnline(int)), m_awayManager, TQT_SLOT(identityOnline(int)));
-        connect(m_connectionManager, TQT_SIGNAL(identityOffline(int)), m_awayManager, TQT_SLOT(identityOffline(int)));
-        connect(m_connectionManager, TQT_SIGNAL(identityOffline(int)), m_awayManager, TQT_SLOT(identityOffline(int)));
-        connect(m_connectionManager, TQT_SIGNAL(connectionChangedAwayState(bool)), m_awayManager, TQT_SLOT(updateGlobalAwayAction(bool)));
+        connect(m_connectionManager, TQ_SIGNAL(identityOnline(int)), m_awayManager, TQ_SLOT(identityOnline(int)));
+        connect(m_connectionManager, TQ_SIGNAL(identityOffline(int)), m_awayManager, TQ_SLOT(identityOffline(int)));
+        connect(m_connectionManager, TQ_SIGNAL(identityOffline(int)), m_awayManager, TQ_SLOT(identityOffline(int)));
+        connect(m_connectionManager, TQ_SIGNAL(connectionChangedAwayState(bool)), m_awayManager, TQ_SLOT(updateGlobalAwayAction(bool)));
 
         // an instance of DccTransferManager needs to be created before GUI class instances' creation.
-        m_dccTransferManager = new DccTransferManager(TQT_TQOBJECT(this));
+        m_dccTransferManager = new DccTransferManager(this);
 
         // make sure all vars are initialized properly
         quickConnectDialog = 0;
 
         // Sound object used to play sound...
-        m_sound = new Konversation::Sound(TQT_TQOBJECT(this));
+        m_sound = new Konversation::Sound(this);
 
         // initialize OSD display here, so we can read the Preferences::properly
         osd = new OSDWidget( "Konversation" );
@@ -107,7 +107,7 @@ int KonversationApplication::newInstance()
 
         // Images object providing LEDs, NickIcons
         m_images = new Images();
-        connect(this, TQT_SIGNAL(iconChanged(int)), m_images, TQT_SLOT(updateIcons()));
+        connect(this, TQ_SIGNAL(iconChanged(int)), m_images, TQ_SLOT(updateIcons()));
 
         // Auto-alias scripts.  This adds any missing aliases
         TQStringList aliasList(Preferences::aliasList());
@@ -131,9 +131,9 @@ int KonversationApplication::newInstance()
         mainWindow = new KonversationMainWindow();
         setMainWidget(mainWindow);
 
-        connect(mainWindow, TQT_SIGNAL(showQuickConnectDialog()), this, TQT_SLOT(openQuickConnectDialog()) );
-        connect(Preferences::self(), TQT_SIGNAL(updateTrayIcon()), mainWindow, TQT_SLOT(updateTrayIcon()) );
-        connect(osd, TQT_SIGNAL(hidden()), mainWindow, TQT_SIGNAL(endNotification()));
+        connect(mainWindow, TQ_SIGNAL(showQuickConnectDialog()), this, TQ_SLOT(openQuickConnectDialog()) );
+        connect(Preferences::self(), TQ_SIGNAL(updateTrayIcon()), mainWindow, TQ_SLOT(updateTrayIcon()) );
+        connect(osd, TQ_SIGNAL(hidden()), mainWindow, TQ_SIGNAL(endNotification()));
         // take care of user style changes, setting back colors and stuff
 
         // apply GUI settings
@@ -163,7 +163,7 @@ int KonversationApplication::newInstance()
 
         if (openServerList) mainWindow->openServerList();
 
-        connect(this, TQT_SIGNAL(serverGroupsChanged(const Konversation::ServerGroupSettings*)), this, TQT_SLOT(saveOptions()));
+        connect(this, TQ_SIGNAL(serverGroupsChanged(const Konversation::ServerGroupSettings*)), this, TQ_SLOT(saveOptions()));
 
         // prepare dcop interface
         dcopObject = new KonvDCOP;
@@ -172,18 +172,18 @@ int KonversationApplication::newInstance()
 
         if (dcopObject)
         {
-            connect(dcopObject,TQT_SIGNAL (dcopMultiServerRaw(const TQString&)),
-                this,TQT_SLOT (dcopMultiServerRaw(const TQString&)) );
-            connect(dcopObject,TQT_SIGNAL (dcopRaw(const TQString&,const TQString&)),
-                this,TQT_SLOT (dcopRaw(const TQString&,const TQString&)) );
-            connect(dcopObject,TQT_SIGNAL (dcopSay(const TQString&,const TQString&,const TQString&)),
-                this,TQT_SLOT (dcopSay(const TQString&,const TQString&,const TQString&)) );
-            connect(dcopObject,TQT_SIGNAL (dcopInfo(const TQString&)),
-                this,TQT_SLOT (dcopInfo(const TQString&)) );
-            connect(dcopObject,TQT_SIGNAL (dcopInsertMarkerLine()),
-                mainWindow,TQT_SIGNAL(insertMarkerLine()));
-            connect(dcopObject, TQT_SIGNAL(connectTo(Konversation::ConnectionFlag, const TQString&, const TQString&, const TQString&, const TQString&, const TQString&, bool)),
-                m_connectionManager, TQT_SLOT(connectTo(Konversation::ConnectionFlag, const TQString&, const TQString&, const TQString&, const TQString&, const TQString&, bool)));
+            connect(dcopObject,TQ_SIGNAL (dcopMultiServerRaw(const TQString&)),
+                this,TQ_SLOT (dcopMultiServerRaw(const TQString&)) );
+            connect(dcopObject,TQ_SIGNAL (dcopRaw(const TQString&,const TQString&)),
+                this,TQ_SLOT (dcopRaw(const TQString&,const TQString&)) );
+            connect(dcopObject,TQ_SIGNAL (dcopSay(const TQString&,const TQString&,const TQString&)),
+                this,TQ_SLOT (dcopSay(const TQString&,const TQString&,const TQString&)) );
+            connect(dcopObject,TQ_SIGNAL (dcopInfo(const TQString&)),
+                this,TQ_SLOT (dcopInfo(const TQString&)) );
+            connect(dcopObject,TQ_SIGNAL (dcopInsertMarkerLine()),
+                mainWindow,TQ_SIGNAL(insertMarkerLine()));
+            connect(dcopObject, TQ_SIGNAL(connectTo(Konversation::ConnectionFlag, const TQString&, const TQString&, const TQString&, const TQString&, const TQString&, bool)),
+                m_connectionManager, TQ_SLOT(connectTo(Konversation::ConnectionFlag, const TQString&, const TQString&, const TQString&, const TQString&, const TQString&, bool)));
         }
 
         m_notificationHandler = new Konversation::NotificationHandler(this);
@@ -773,9 +773,9 @@ void KonversationApplication::clearUrlList()
 void KonversationApplication::openQuickConnectDialog()
 {
     quickConnectDialog = new QuickConnectDialog(mainWindow);
-    connect(quickConnectDialog, TQT_SIGNAL(connectClicked(Konversation::ConnectionFlag, const TQString&, const TQString&,
+    connect(quickConnectDialog, TQ_SIGNAL(connectClicked(Konversation::ConnectionFlag, const TQString&, const TQString&,
         const TQString&, const TQString&, const TQString&, bool)),
-        m_connectionManager, TQT_SLOT(connectTo(Konversation::ConnectionFlag, const TQString&, const TQString&,
+        m_connectionManager, TQ_SLOT(connectTo(Konversation::ConnectionFlag, const TQString&, const TQString&,
         const TQString&, const TQString&, const TQString&, bool)));
     quickConnectDialog->show();
 }
@@ -883,6 +883,3 @@ TQString KonversationApplication::doAutoreplace(const TQString& text,bool output
 }
 
 #include "konversationapplication.moc"
-
-// kate: space-indent on; tab-width 4; indent-width 4; mixed-indent off; replace-tabs on;
-// vim: set et sw=4 ts=4 cino=l1,cs,U1:
