@@ -27,7 +27,7 @@ namespace Konversation
     */
     class Sound : public TQObject
     {
-        Q_OBJECT
+        TQ_OBJECT
   
 
         public:
