@@ -20,7 +20,7 @@ class Server;
 
 class ScriptLauncher : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
