@@ -26,7 +26,7 @@ class TDEListViewSearchLineWidget;
 
 class UrlCatcher : public ChatWindow
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
         public:
